Running a Job
=============

After creating a new job, or opening an existing job, you may run the simulation by clicking the <Run> button.  A window will appear, showing the progress of simulation execution for each selected Profile.   At the end of the simulation run, close the window and return to the main user interface. This can be done by standard Windows procedures (i.e., clicking the X at the top right corner, using File / Exit from the menu, or using Alt / F4 keys).

You may now examine the results by clicking the <Check Output> menu, or perform other tasks from the main user interface.

Note:   Before creating and running a job, you must make sure that all the necessary input files have been prepared and saved in their correct folders.
